@@ -358,6 +358,19 @@ class Status(object):
 		return 'Your branch is up to date with' in status
 
 
+	def getUpstream(self):
+		"""
+		return the current upstream of the repository
+		:return:
+		"""
+		status = subprocess.run(f'git -C {str(self._directory)} status', capture_output=True, text=True, shell=True).stdout.strip()
+		match = re.search('Your branch is .* \'(.+?)\'', status)
+		if match:
+			return match.group(1)
+		else:
+			return None
+
+
 	def changes(self) -> dict:
 		"""
 		get changed files with their type (unstaged, modified etc.)
@@ -372,7 +385,6 @@ class Status(object):
 		return changes
 
 
-
 class Remote(object):
 
 	def __init__(self, repository: Repository, name: str = None, url: str = None, user: str = None, type: str = '', remoteString: str = None):
